@@ -16,15 +16,6 @@ utc_date = function (date) {
 # NOTE: cannot handle mixed vectors of POSIXlt and POSIXct
 date_as_isostring = function (date) format.Date(date, format = '%FT%TZ')
 
-#' Simple factory function meant to implement dplyr functions for other classes,
-#' which call an callback to attach the original class again after the fact.
-#'
-#' @param callback The function to call after the dplyr function
-#' @noRd
-dplyr_class_wrapper = function(callback) {
-  function(.data, ..., .dots) callback(NextMethod())
-}
-
 #' Checks for an interactive session using interactive() and a knitr process in
 #' the callstack. See https://stackoverflow.com/a/33108841
 #'
@@ -33,3 +24,13 @@ is_non_interactive = function () {
   ff = sapply(sys.calls(), function(f) as.character(f[1]))
   any(ff %in% c('knit2html', 'render')) || !interactive()
 }
+
+#' custom recursive lapply with better handling of NULL values
+#' from https://stackoverflow.com/a/38950304
+#' @noRd
+recursive_lapply = function(x, fn) {
+  if (is.list(x))
+    lapply(x, recursive_lapply, fn)
+  else
+    fn(x)
+}
